export DEBFULLNAME="Cuong Tham"
dh_make --createorig --single -e cuongtham@gmail.com -c gpl
dpkg-buildpackage -rfakeroot -sa -S
scp ../symfonie_0.1-1_armel.deb root@192.168.1.150:/home/user
